==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkBooleanTexture.java <==
// java wrapper for vtkBooleanTexture object
//

package vtk;
import vtk.*;

public class vtkBooleanTexture extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetXSize_2(int id0);
  public void SetXSize(int id0)
    { SetXSize_2(id0); }

  private native int GetXSize_3();
  public int GetXSize()
    { return GetXSize_3(); }

  private native void SetYSize_4(int id0);
  public void SetYSize(int id0)
    { SetYSize_4(id0); }

  private native int GetYSize_5();
  public int GetYSize()
    { return GetYSize_5(); }

  private native void SetThickness_6(int id0);
  public void SetThickness(int id0)
    { SetThickness_6(id0); }

  private native int GetThickness_7();
  public int GetThickness()
    { return GetThickness_7(); }

  private native void SetInIn_8(char id0,char id1);
  public void SetInIn(char id0,char id1)
    { SetInIn_8(id0,id1); }

  private native byte[] GetInIn_9();
  public byte[] GetInIn()
    { return GetInIn_9(); }

  private native void SetInOut_10(char id0,char id1);
  public void SetInOut(char id0,char id1)
    { SetInOut_10(id0,id1); }

  private native byte[] GetInOut_11();
  public byte[] GetInOut()
    { return GetInOut_11(); }

  private native void SetOutIn_12(char id0,char id1);
  public void SetOutIn(char id0,char id1)
    { SetOutIn_12(id0,id1); }

  private native byte[] GetOutIn_13();
  public byte[] GetOutIn()
    { return GetOutIn_13(); }

  private native void SetOutOut_14(char id0,char id1);
  public void SetOutOut(char id0,char id1)
    { SetOutOut_14(id0,id1); }

  private native byte[] GetOutOut_15();
  public byte[] GetOutOut()
    { return GetOutOut_15(); }

  private native void SetOnOn_16(char id0,char id1);
  public void SetOnOn(char id0,char id1)
    { SetOnOn_16(id0,id1); }

  private native byte[] GetOnOn_17();
  public byte[] GetOnOn()
    { return GetOnOn_17(); }

  private native void SetOnIn_18(char id0,char id1);
  public void SetOnIn(char id0,char id1)
    { SetOnIn_18(id0,id1); }

  private native byte[] GetOnIn_19();
  public byte[] GetOnIn()
    { return GetOnIn_19(); }

  private native void SetOnOut_20(char id0,char id1);
  public void SetOnOut(char id0,char id1)
    { SetOnOut_20(id0,id1); }

  private native byte[] GetOnOut_21();
  public byte[] GetOnOut()
    { return GetOnOut_21(); }

  private native void SetInOn_22(char id0,char id1);
  public void SetInOn(char id0,char id1)
    { SetInOn_22(id0,id1); }

  private native byte[] GetInOn_23();
  public byte[] GetInOn()
    { return GetInOn_23(); }

  private native void SetOutOn_24(char id0,char id1);
  public void SetOutOn(char id0,char id1)
    { SetOutOn_24(id0,id1); }

  private native byte[] GetOutOn_25();
  public byte[] GetOutOn()
    { return GetOutOn_25(); }

  public vtkBooleanTexture() { super(); }

  public vtkBooleanTexture(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv7h.pkg.tar.xz: vtk/vtkBooleanTexture.java <==
// java wrapper for vtkBooleanTexture object
//

package vtk;
import vtk.*;

public class vtkBooleanTexture extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetXSize_2(int id0);
  public void SetXSize(int id0)
    { SetXSize_2(id0); }

  private native int GetXSize_3();
  public int GetXSize()
    { return GetXSize_3(); }

  private native void SetYSize_4(int id0);
  public void SetYSize(int id0)
    { SetYSize_4(id0); }

  private native int GetYSize_5();
  public int GetYSize()
    { return GetYSize_5(); }

  private native void SetThickness_6(int id0);
  public void SetThickness(int id0)
    { SetThickness_6(id0); }

  private native int GetThickness_7();
  public int GetThickness()
    { return GetThickness_7(); }

  private native void SetInIn_8(char id0,char id1);
  public void SetInIn(char id0,char id1)
    { SetInIn_8(id0,id1); }

  private native byte[] GetInIn_9();
  public byte[] GetInIn()
    { return GetInIn_9(); }

  private native void SetInOut_10(char id0,char id1);
  public void SetInOut(char id0,char id1)
    { SetInOut_10(id0,id1); }

  private native byte[] GetInOut_11();
  public byte[] GetInOut()
    { return GetInOut_11(); }

  private native void SetOutIn_12(char id0,char id1);
  public void SetOutIn(char id0,char id1)
    { SetOutIn_12(id0,id1); }

  private native byte[] GetOutIn_13();
  public byte[] GetOutIn()
    { return GetOutIn_13(); }

  private native void SetOutOut_14(char id0,char id1);
  public void SetOutOut(char id0,char id1)
    { SetOutOut_14(id0,id1); }

  private native byte[] GetOutOut_15();
  public byte[] GetOutOut()
    { return GetOutOut_15(); }

  private native void SetOnOn_16(char id0,char id1);
  public void SetOnOn(char id0,char id1)
    { SetOnOn_16(id0,id1); }

  private native byte[] GetOnOn_17();
  public byte[] GetOnOn()
    { return GetOnOn_17(); }

  private native void SetOnIn_18(char id0,char id1);
  public void SetOnIn(char id0,char id1)
    { SetOnIn_18(id0,id1); }

  private native byte[] GetOnIn_19();
  public byte[] GetOnIn()
    { return GetOnIn_19(); }

  private native void SetOnOut_20(char id0,char id1);
  public void SetOnOut(char id0,char id1)
    { SetOnOut_20(id0,id1); }

  private native byte[] GetOnOut_21();
  public byte[] GetOnOut()
    { return GetOnOut_21(); }

  private native void SetInOn_22(char id0,char id1);
  public void SetInOn(char id0,char id1)
    { SetInOn_22(id0,id1); }

  private native byte[] GetInOn_23();
  public byte[] GetInOn()
    { return GetInOn_23(); }

  private native void SetOutOn_24(char id0,char id1);
  public void SetOutOn(char id0,char id1)
    { SetOutOn_24(id0,id1); }

  private native byte[] GetOutOn_25();
  public byte[] GetOutOn()
    { return GetOutOn_25(); }

  public vtkBooleanTexture() { super(); }

  public vtkBooleanTexture(long id) { super(id); }
  public native long   VTKInit();

}
